[Buildbot-commits] buildbot/buildbot/test test_vc.py,1.37,1.38

Brian Warner warner at users.sourceforge.net
Wed Aug 10 08:15:47 UTC 2005


Update of /cvsroot/buildbot/buildbot/buildbot/test
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv8539/buildbot/test

Modified Files:
	test_vc.py 
Log Message:
Revision: arch at buildbot.sf.net--2004/buildbot--dev--0--patch-275
Creator:  Brian Warner <warner at lothar.com>

jobdir-style 'try' framework is now 90% implemented

	* buildbot/scripts/runner.py: Add 'buildbot try' command, jobdir
	style is 90% done, still missing status reporting or waiting for
	the buildsets to finish, and it is completely untested.

	* buildbot/trybuild.py: delete file, move contents to ..
	* buildbot/scripts/tryclient.py (getSourceStamp): .. here
	* buildbot/test/test_vc.py: match the move


Index: test_vc.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/test/test_vc.py,v
retrieving revision 1.37
retrieving revision 1.38
diff -u -d -r1.37 -r1.38
--- test_vc.py	3 Aug 2005 23:47:29 -0000	1.37
+++ test_vc.py	10 Aug 2005 08:15:44 -0000	1.38
@@ -13,13 +13,14 @@
 from twisted.python import log
 #log.startLogging(sys.stderr)
 
-from buildbot import master, interfaces, trybuild
+from buildbot import master, interfaces
 from buildbot.slave import bot
 from buildbot.status.builder import SUCCESS, FAILURE
 from buildbot.process import step, base
 from buildbot.changes import changes
 from buildbot.sourcestamp import SourceStamp
 from buildbot.twcompat import maybeWait
+from buildbot.scripts import tryclient
 
 # buildbot.twcompat will patch these into t.i.defer if necessary
 from twisted.internet.defer import waitForDeferred, deferredGenerator
@@ -696,12 +697,12 @@
         d.addCallback(self._doGetpatch_1, workdir)
         return d
     def _doGetpatch_1(self, res, workdir):
-        d = trybuild.getSourceStamp(self.vctype, workdir)
+        d = tryclient.getSourceStamp(self.vctype, workdir)
         return d
 
     def dumpPatch(self, patch):
         # this exists to help me figure out the right 'patchlevel' value
         # should be returned by trybuild.getSourceStamp
         n = self.mktemp()
         open(n,"w").write(patch)
         d = self.runCommand(".", ["lsdiff", n])
@@ -696,12 +697,12 @@
     def dumpPatch(self, patch):
         # this exists to help me figure out the right 'patchlevel' value
-        # should be returned by trybuild.getSourceStamp
+        # should be returned by tryclient.getSourceStamp
         n = self.mktemp()
         open(n,"w").write(patch)





More information about the Commits mailing list